# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add needsLustre to lustre-needing workflows

Revision ID: 77b4647443bd
Revises: 1d653467ede6
Create Date: 2021-08-11 23:02:07.327306

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "77b4647443bd"
down_revision = "1d653467ede6"
branch_labels = None
depends_on = None

lustre_needing_workflows = [
    "test_download",
    "std_calibration",
    "std_cms_imaging",
    "ingest_image",
    "ingest_cal",
    "restore_cms",
    "std_restore_imaging",
]


def upgrade():
    for wf in lustre_needing_workflows:
        op.execute(
            f"UPDATE workflow_templates SET content = regexp_replace(convert_from(content, 'utf-8'), E'queue', E'requirements = HasLustre == True\n\nqueue')::bytea WHERE filename = '{wf}.condor'"
        )


def downgrade():
    for wf in lustre_needing_workflows:
        op.execute(
            f"UPDATE workflow_templates SET content = regexp_replace(convert_from(content, 'utf-8'), E'requirements = HasLustre == True\n\nqueue', E'queue')::bytea WHERE filename = '{wf}.condor'"
        )
